% This function is used to generate the tcl file that defines the  
% infill struts for a 3D Model in OpenSees     
function defineInfillStruts3DModel(buildingGeometry,...
    xInfillObjects,zInfillObjects,BuildingModelDirectory,...
    XInfillPropertiesLocation,ZInfillPropertiesLocation,...
    AnalysisType)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%             Generating Tcl File with Infill Struts Defined              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    
    % Load text file with X-Direction infill strut locations
    cd(XInfillPropertiesLocation)
    xInfillLocation = load('xInfillLocation.txt');    
    
    % Load text file with Z infill strut locations
    cd(ZInfillPropertiesLocation)
    zInfillLocation = load('zInfillLocation.txt');
    
    % Go to model data direction
    cd(BuildingModelDirectory)

    % Make folder used to store OpenSees models
    cd OpenSees3DModels
    cd(AnalysisType)

    % Opening and defining Tcl file
    fid = fopen('DefineInfillStruts3DModel.tcl','wt');

    % Writing file description into tcl file
    fprintf(fid,'%s\n','# This file will be used to define infill struts');
    fprintf(fid,'%s\n','');
    fprintf(fid,'%s\n','');

    % Defining infill struts
    fprintf(fid,'%s\n','# Define infills');
    % Looping over all stories
    for i = 1:buildingGeometry.numberOfStories
        % Defining X-Direction infill struts
        fprintf(fid,'%s\n','# X-Direction Infill Struts');
        % Loop over the number of Z-Direction column lines
        for j = 1:buildingGeometry.numberOfZBays + 1
            % Loop over number of X-Direction bays
            for k = 1:buildingGeometry.numberOfXBays
                    if xInfillLocation(i,(j - 1)*...
                        buildingGeometry.numberOfXBays + k) == 1
                    % Central east-west strut
                    fprintf(fid,'%s\t','element');
                    fprintf(fid,'%s\t','truss');
                    fprintf(fid,'%s\t',...
                        xInfillObjects{i,k,j}. ...
                        centralEastWestStrutOpenSeesTag);
                    fprintf(fid,'%s\t',...
                        xInfillObjects{i,k,j}. ...
                        centralEastWestStrutStartNodeOpenSeesTag);
                    fprintf(fid,'%s\t',...
                        xInfillObjects{i,k,j}. ...
                        centralEastWestStrutEndNodeOpenSeesTag);
                    fprintf(fid,'%u\t',1.0);
                    fprintf(fid,'%s',strcat(...
                        '$CentralStrutXStory',...
                    num2str(i),'Bay',num2str(k),'Line',num2str(j)));
                    fprintf(fid,'%s\n',';');
                    
                    % Offset east-west strut
                    fprintf(fid,'%s\t','element');
                    fprintf(fid,'%s\t','truss');
                    fprintf(fid,'%s\t',...
                        xInfillObjects{i,k,j}. ...
                        offsetEastWestStrutOpenSeesTag);
                    fprintf(fid,'%s\t',...
                        xInfillObjects{i,k,j}. ...
                        offsetEastWestStrutStartNodeOpenSeesTag);
                    fprintf(fid,'%s\t',...
                        xInfillObjects{i,k,j}. ...
                        offsetEastWestStrutEndNodeOpenSeesTag);
                    fprintf(fid,'%u\t',1.0);
                    fprintf(fid,'%s',strcat(...
                        '$OffsetStrutXStory',...
                    num2str(i),'Bay',num2str(k),'Line',num2str(j)));
                    fprintf(fid,'%s\n',';');

                    % Central west-east strut
                    if strcmp(AnalysisType,'EigenValueAnalysis') ~= 1 
                        fprintf(fid,'%s\t','element');
                        fprintf(fid,'%s\t','truss');
                        fprintf(fid,'%s\t',...
                            xInfillObjects{i,k,j}. ...
                            centralWestEastStrutOpenSeesTag);
                        fprintf(fid,'%s\t',...
                            xInfillObjects{i,k,j}. ...
                            centralWestEastStrutStartNodeOpenSeesTag);
                        fprintf(fid,'%s\t',...
                            xInfillObjects{i,k,j}. ...
                            centralWestEastStrutEndNodeOpenSeesTag);
                        fprintf(fid,'%u\t',1.0);
                        fprintf(fid,'%s',strcat(...
                            '$CentralStrutXStory',...
                        num2str(i),'Bay',num2str(k),'Line',num2str(j)));
                        fprintf(fid,'%s\n',';');

                        % Offset west-east strut
                        fprintf(fid,'%s\t','element');
                        fprintf(fid,'%s\t','truss');
                        fprintf(fid,'%s\t',...
                            xInfillObjects{i,k,j}. ...
                            offsetWestEastStrutOpenSeesTag);
                        fprintf(fid,'%s\t',...
                            xInfillObjects{i,k,j}. ...
                            offsetWestEastStrutStartNodeOpenSeesTag);
                        fprintf(fid,'%s\t',...
                            xInfillObjects{i,k,j}. ...
                            offsetWestEastStrutEndNodeOpenSeesTag);
                        fprintf(fid,'%u\t',1.0);
                        fprintf(fid,'%s',strcat(...
                            '$OffsetStrutXStory',num2str(i),...
                            'Bay',num2str(k),'Line',num2str(j)));
                        fprintf(fid,'%s\n',';');
                    end
                    end        
            end
        end
        fprintf(fid,'%s\n','');

        % Defining Z-Direction infill struts
        fprintf(fid,'%s\n','# Z-Direction  Infill Struts');
        % Loop over the number of Z-Direction bays
        for j = 1:buildingGeometry.numberOfZBays
            % Loop over number of X-Direction column lines
            for k = 1:buildingGeometry.numberOfXBays + 1
                    if zInfillLocation(i,(j - 1)*...
                        (buildingGeometry.numberOfXBays + 1) + k) == 1
                    % Central south-north strut
                    if strcmp(AnalysisType,'EigenValueAnalysis') ~= 1 
                        fprintf(fid,'%s\t','element');
                        fprintf(fid,'%s\t','truss');
                        fprintf(fid,'%s\t',...
                            zInfillObjects{i,k,j}. ...
                            centralSouthNorthStrutOpenSeesTag);
                        fprintf(fid,'%s\t',...
                            zInfillObjects{i,k,j}. ...
                            centralSouthNorthStrutStartNodeOpenSeesTag);
                        fprintf(fid,'%s\t',...
                            zInfillObjects{i,k,j}. ...
                            centralSouthNorthStrutEndNodeOpenSeesTag);
                        fprintf(fid,'%u\t',1.0);
                        fprintf(fid,'%s',strcat(...
                            '$CentralStrutZStory',...
                        num2str(i),'Bay',num2str(j),'Line',num2str(k)));
                        fprintf(fid,'%s\n',';');

                        % Offset south-north strut
                        fprintf(fid,'%s\t','element');
                        fprintf(fid,'%s\t','truss');
                        fprintf(fid,'%s\t',...
                            zInfillObjects{i,k,j}. ...
                            offsetSouthNorthStrutOpenSeesTag);
                        fprintf(fid,'%s\t',...
                            zInfillObjects{i,k,j}. ...
                            offsetSouthNorthStrutStartNodeOpenSeesTag);
                        fprintf(fid,'%s\t',...
                            zInfillObjects{i,k,j}. ...
                            offsetSouthNorthStrutEndNodeOpenSeesTag);
                        fprintf(fid,'%u\t',1.0);
                        fprintf(fid,'%s',strcat(...
                            '$OffsetStrutZStory',...
                        num2str(i),'Bay',num2str(j),'Line',num2str(k)));
                        fprintf(fid,'%s\n',';');
                    end

                    % Central north-south strut
                    fprintf(fid,'%s\t','element');
                    fprintf(fid,'%s\t','truss');
                    fprintf(fid,'%1s\t',...
                        zInfillObjects{i,k,j}. ...
                        centralNorthSouthStrutOpenSeesTag);
                    fprintf(fid,'%s\t',...
                        zInfillObjects{i,k,j}. ...
                        centralNorthSouthStrutStartNodeOpenSeesTag);
                    fprintf(fid,'%s\t',...
                        zInfillObjects{i,k,j}. ...
                        centralNorthSouthStrutEndNodeOpenSeesTag);
                    fprintf(fid,'%u\t',1.0);
                    fprintf(fid,'%s',strcat(...
                        '$CentralStrutZStory',...
                    num2str(i),'Bay',num2str(j),'Line',num2str(k)));
                    fprintf(fid,'%s\n',';');
                    
                    % Offset north-south strut
                    fprintf(fid,'%s\t','element');
                    fprintf(fid,'%s\t','truss');
                    fprintf(fid,'%s\t',...
                        zInfillObjects{i,k,j}. ...
                        offsetNorthSouthStrutOpenSeesTag);
                    fprintf(fid,'%s\t',...
                        zInfillObjects{i,k,j}. ...
                        offsetNorthSouthStrutStartNodeOpenSeesTag);
                    fprintf(fid,'%s\t',...
                        zInfillObjects{i,k,j}. ...
                        offsetNorthSouthStrutEndNodeOpenSeesTag);
                    fprintf(fid,'%u\t',1.0);
                    fprintf(fid,'%s',strcat(...
                        '$OffsetStrutZStory',...
                    num2str(i),'Bay',num2str(j),'Line',num2str(k)));
                    fprintf(fid,'%s\n',';');
                    end        
            end
        end
        fprintf(fid,'%s\n','');
    end    
    fprintf(fid,'%s\n','puts "infill struts defined"');
    fprintf(fid,'%s\n','');

    % Closing and saving tcl file
    fclose(fid);
end

